@@ -3,6 +3,7 @@ import sys
 import afl
 
 def main():
+    sys.stdin.seek(0)  # work-around for C stdio caching EOF status
     s = sys.stdin.read()
     if len(s) < 1:
         print('Hum?')
@@ -14,6 +15,7 @@ def main():
         print('A non-zero value? How quaint!')
 
 if __name__ == '__main__':
+    ''.encode('ASCII')  # make sure the codec module is loaded before the loop
     while afl.loop():
         main()
 
