@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2015-2017 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2018 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -45,6 +45,7 @@ from .tools import (
     SkipTest,
     assert_true,
     clean_environ,
+    require_commands,
     tempdir,
 )
 
@@ -55,13 +56,14 @@ if not isinstance(token, str):
     token = token.decode('ASCII')
 
 def get_afl_version():
+    require_commands('afl-fuzz')
     child = ipc.Popen(['afl-fuzz'], stdout=ipc.PIPE)
     version = child.stdout.readline()
     child.stdout.close()
     child.wait()
     if str is not bytes:
         version = version.decode('ASCII')
-    version = re.sub(r'\x1b\[[^m]+m', '', version)
+    version = re.sub(r'\x1B\[[^m]+m', '', version)
     match = re.match(r'^afl-fuzz\s+([0-9.]+)b?\b', version)
     version = match.group(1)
     return distutils.version.StrictVersion(version)
@@ -80,6 +82,7 @@ def check_core_pattern():
             raise SkipTest('/proc/sys/kernel/core_pattern = ' + pattern)
 
 def _test_fuzz(workdir, target, dumb=False):
+    require_commands('py-afl-fuzz', 'afl-fuzz')
     input_dir = workdir + '/in'
     output_dir = workdir + '/out'
     os.mkdir(input_dir)
